@@ -12,7 +12,11 @@ class ExternalTypeFactory(SchemaFactoryABC):
     priority: int = 120
 
     def from_type(
-        self, type_: Type, context: SchemaContext, path: str
+        self,
+        type_: Type,
+        context: SchemaContext,
+        path: str,
+        ref_schemas: Dict[Type, Schema],
     ) -> Optional[Schema]:
         if type_ == ExternalItemType:
             return Schema({"type": "object", "additionalProperties": True}, type_)
